@@ -13,7 +13,123 @@ import re
 import scipy.optimize as spo
 import sys
 from collections import defaultdict
+import deprecation
 
+__version__ = "4.2.0"
+
+# Dictionary of relative atomic masses
+ram_dict = {
+    "H": 1.0076,
+    "He": 4.0026,
+    "Li": 6.941,
+    "Be": 9.0122,
+    "B": 10.811,
+    "C": 12.0107,
+    "N": 14.0067,
+    "O": 15.9994,
+    "F": 18.9984,
+    "Ne": 20.1797,
+    "Na": 22.9897,
+    "Mg": 24.305,
+    "Al": 26.9815,
+    "Si": 28.0855,
+    "P": 30.9738,
+    "S": 32.065,
+    "Cl": 35.453,
+    "K": 39.0983,
+    "Ar": 39.948,
+    "Ca": 40.078,
+    "Sc": 44.9559,
+    "Ti": 47.867,
+    "V": 50.9415,
+    "Cr": 51.9961,
+    "Mn": 54.938,
+    "Fe": 55.845,
+    "Ni": 58.6934,
+    "Co": 58.9332,
+    "Cu": 63.546,
+    "Zn": 65.39,
+    "Ga": 69.723,
+    "Ge": 72.64,
+    "As": 74.9216,
+    "Se": 78.96,
+    "Br": 79.904,
+    "Kr": 83.8,
+    "Rb": 85.4678,
+    "Sr": 87.62,
+    "Y": 88.9059,
+    "Zr": 91.224,
+    "Nb": 92.9064,
+    "Mo": 95.94,
+    "Tc": 98,
+    "Ru": 101.07,
+    "Rh": 102.9055,
+    "Pd": 106.42,
+    "Ag": 107.8682,
+    "Cd": 112.411,
+    "In": 114.818,
+    "Sn": 118.71,
+    "Sb": 121.76,
+    "I": 126.9045,
+    "Te": 127.6,
+    "Xe": 131.293,
+    "Cs": 132.9055,
+    "Ba": 137.327,
+    "La": 138.9055,
+    "Ce": 140.116,
+    "Pr": 140.9077,
+    "Nd": 144.24,
+    "Pm": 145,
+    "Sm": 150.36,
+    "Eu": 151.964,
+    "Gd": 157.25,
+    "Tb": 158.9253,
+    "Dy": 162.5,
+    "Ho": 164.9303,
+    "Er": 167.259,
+    "Tm": 168.9342,
+    "Yb": 173.04,
+    "Lu": 174.967,
+    "Hf": 178.49,
+    "Ta": 180.9479,
+    "W": 183.84,
+    "Re": 186.207,
+    "Os": 190.23,
+    "Ir": 192.217,
+    "Pt": 195.078,
+    "Au": 196.9665,
+    "Hg": 200.59,
+    "Tl": 204.3833,
+    "Pb": 207.2,
+    "Bi": 208.9804,
+    "Po": 209,
+    "At": 210,
+    "Rn": 222,
+    "Fr": 223,
+    "Ra": 226,
+    "Ac": 227,
+    "Pa": 231.0359,
+    "Th": 232.0381,
+    "Np": 237,
+    "U": 238.0289,
+    "Am": 243,
+    "Pu": 244,
+    "Cm": 247,
+    "Bk": 247,
+    "Cf": 251,
+    "Es": 252,
+    "Fm": 257,
+    "Md": 258,
+    "No": 259,
+    "Rf": 261,
+    "Lr": 262,
+    "Db": 262,
+    "Bh": 264,
+    "Sg": 266,
+    "Mt": 268,
+    "Rg": 272,
+    "Hs": 277
+}
 
 atom_lab_num = {"H": 1, "He": 2, "Li": 3, "Be": 4, "B": 5, "C": 6, "N": 7,
                 "O": 8, "F": 9, "Ne": 10, "Na": 11, "Mg": 12, "Al": 13,
@@ -68,9 +184,9 @@ def load_xyz(f_name: str, atomic_numbers: bool = False,
 
     Returns
     -------
-    _labels : list
+    list
         atomic labels
-    _coords : np.ndarray
+    np.ndarray
         (n_atoms,3) array containing xyz coordinates of each atom
     """
 
@@ -154,6 +270,10 @@ def save_xyz(f_name: str, labels: list, coords: np.ndarray,
     return
 
 
+@deprecation.deprecated(
+    deprecated_in="4.2.0", removed_in="5.1.0", current_version=__version__,
+    details="Use the remove_label_indices function instead"
+)
 def remove_numbers(labels: list):
     """
     Remove numbers from a list of atomic labels
@@ -169,18 +289,45 @@ def remove_numbers(labels: list):
         atomic labels without numbers
     """
 
+    return remove_label_indices(labels)
+
+
+def remove_label_indices(labels: list):
+    """
+    Remove label indexing from atomic symbols
+    indexing is either numbers or numbers followed by letters:
+    e.g. H1, H2, H3
+    or H1a, H2a, H3a
+
+    Parameters
+    ----------
+    labels : list
+        atomic labels
+
+    Returns
+    -------
+    list
+        atomic labels without indexing
+    """
+
     labels_nn = []
     for label in labels:
         no_digits = []
         for i in label:
             if not i.isdigit():
                 no_digits.append(i)
+            elif i.isdigit():
+                break
         result = ''.join(no_digits)
         labels_nn.append(result)
 
     return labels_nn
 
 
+@deprecation.deprecated(
+    deprecated_in="4.2.0", removed_in="5.1.0", current_version=__version__,
+    details="Use the add_label_indices function instead"
+)
 def add_numbers(labels: list, style: str = 'per_element'):
     """
     Add numbers to a list of atomic labels
@@ -200,6 +347,28 @@ def add_numbers(labels: list, style: str = 'per_element'):
         atomic labels with numbers
     """
 
+    return add_label_indices(labels, style=style)
+
+
+def add_label_indices(labels: list, style: str = 'per_element'):
+    """
+    Add label indexing to atomic symbols - either element or per atom.
+
+    Parameters
+    ----------
+    labels : list
+        atomic labels
+    style : str, optional
+        {'per_element', 'sequential'}
+            'per_element' : Index by element e.g. Dy1, Dy2, N1, N2, etc.
+            'sequential' : Index the atoms 1->N regardless of element
+
+    Returns
+    -------
+    list
+        atomic labels with indexing
+    """
+
     # remove numbers just in case
     labels_nn = remove_numbers(labels)
 
@@ -208,16 +377,16 @@ def add_numbers(labels: list, style: str = 'per_element'):
         labels_wn = ['{}{:d}'.format(lab, it+1)
                      for (it, lab) in enumerate(labels)]
 
-    # Number by element Dy1, Dy2, N1, N2, etc.
+    # Index by element Dy1, Dy2, N1, N2, etc.
     if style == 'per_element':
-        # Get list of elements
+        # Get list of unique elements
         atoms = set(labels_nn)
         # Create dict to keep track of index of current atom of each element
         atom_count = {atom: 1 for atom in atoms}
         # Create labelled list of elements
         labels_wn = []
         for lab in labels_nn:
-            # Number according to dictionary
+            # Index according to dictionary
             labels_wn.append("{}{:d}".format(lab, atom_count[lab]))
             # Then add one to dictionary
             atom_count[lab] += 1
@@ -480,7 +649,7 @@ def get_neighborlist(labels: list, coords: np.ndarray,
     labels_nn = remove_numbers(labels)
 
     # Load molecule
-    mol = Atoms(''.join(labels_nn), positions=coords)
+    mol = Atoms("".join(labels_nn), positions=coords)
 
     # Define cutoffs for each atom using atomic radii
     cutoffs = neighborlist.natural_cutoffs(mol)
@@ -540,10 +709,10 @@ def get_adjacency(labels: list, coords: np.ndarray, adjust_cutoff: dict = {}):
 
 
 def get_bonds(labels: list, coords: np.ndarray, neigh_list=None,
-              verbose: bool = True, style: bool = 'indices'):
+              verbose: bool = True, style: str = 'indices'):
     """
     Calculate list of atoms between which there is a bond.
-    Using ASE. Only unique angles are retained.
+    Using ASE. Only unique bonds are retained.
     e.g. 0-1 and not 1-0
 
     Parameters
@@ -574,7 +743,7 @@ def get_bonds(labels: list, coords: np.ndarray, neigh_list=None,
     labels_nn = remove_numbers(labels)
 
     # Create molecule object
-    mol = Atoms(''.join(labels_nn), positions=coords)
+    mol = Atoms("".join(labels_nn), positions=coords)
 
     # Get neighbourlist if not provided to function
     if not neigh_list:
@@ -605,8 +774,13 @@ def get_bonds(labels: list, coords: np.ndarray, neigh_list=None,
     n_bonds = len(bonds)
 
     # Set format and convert to atomic labels if requested
-    if style == 'labels':
-        bonds = [[labels[atom1], labels[atom2]] for atom1, atom2 in bonds]
+    if style == "labels":
+        bonds = [
+            [labels[atom1], labels[atom2]]
+            for atom1, atom2 in bonds
+        ]
+    elif style == "indices":
+        pass
     else:
         sys.exit("Unknown style specified")
 
@@ -618,7 +792,7 @@ def get_bonds(labels: list, coords: np.ndarray, neigh_list=None,
 
 
 def get_angles(labels: list, coords: np.ndarray, neigh_list=None,
-               verbose: bool = True, style: bool = 'indices'):
+               verbose: bool = True, style: str = 'indices'):
     """
     Calculate list of atoms between which there is a bond angle.
     Using ASE. Only unique angles are retained.
@@ -652,7 +826,7 @@ def get_angles(labels: list, coords: np.ndarray, neigh_list=None,
     labels_nn = remove_numbers(labels)
 
     # Create molecule object
-    mol = Atoms(''.join(labels_nn), positions=coords)
+    mol = Atoms("".join(labels_nn), positions=coords)
 
     # Get neighbourlist if not provided to function
     if not neigh_list:
@@ -683,9 +857,13 @@ def get_angles(labels: list, coords: np.ndarray, neigh_list=None,
     n_angles = len(angles)
 
     # Set format and convert to atomic labels if requested
-    if style == 'labels':
-        angles = [[labels[atom1], labels[atom2], labels[atom3]]
-                  for atom1, atom2, atom3 in angles]
+    if style == "labels":
+        angles = [
+            [labels[atom1], labels[atom2], labels[atom3]]
+            for atom1, atom2, atom3 in angles
+        ]
+    elif style == "indices":
+        pass
     else:
         sys.exit("Unknown style specified")
 
@@ -697,10 +875,10 @@ def get_angles(labels: list, coords: np.ndarray, neigh_list=None,
 
 
 def get_dihedrals(labels: list, coords: np.ndarray, neigh_list=None,
-                  verbose: bool = True, style: bool = 'indices'):
+                  verbose: bool = True, style: str = 'indices'):
     """
     Calculate and list of atoms between which there is a dihedral.
-    Using ASE. Only unique angles are retained.
+    Using ASE. Only unique dihedrals are retained.
     e.g. 0-1-2-3 but not 3-2-1-0
 
     Parameters
@@ -731,7 +909,7 @@ def get_dihedrals(labels: list, coords: np.ndarray, neigh_list=None,
     labels_nn = remove_numbers(labels)
 
     # Create molecule object
-    mol = Atoms(''.join(labels_nn), positions=coords)
+    mol = Atoms("".join(labels_nn), positions=coords)
 
     # Get neighbourlist if not provided to function
     if not neigh_list:
@@ -762,16 +940,18 @@ def get_dihedrals(labels: list, coords: np.ndarray, neigh_list=None,
     n_dihedrals = len(dihedrals)
 
     # Set format and convert to atomic labels if requested
-    if style == 'labels':
+    if style == "labels":
         dihedrals = [
-                     [
-                      labels[atom1],
-                      labels[atom2],
-                      labels[atom3],
-                      labels[atom4]
-                     ]
-                     for atom1, atom2, atom3, atom4 in dihedrals
-                    ]
+            [
+                labels[atom1],
+                labels[atom2],
+                labels[atom3],
+                labels[atom4]
+            ]
+            for atom1, atom2, atom3, atom4 in dihedrals
+        ]
+    elif style == "indices":
+        pass
     else:
         sys.exit("Unknown style specified")
 
@@ -783,7 +963,7 @@ def get_dihedrals(labels: list, coords: np.ndarray, neigh_list=None,
 
 
 def lab_to_num(labels: list):
-    '''
+    """
     Convert atomic label to atomic number
 
     Parameters
@@ -795,7 +975,7 @@ def lab_to_num(labels: list):
     -------
     list
         Atomic numbers
-    '''
+    """
 
     labels_nn = remove_numbers(labels)
 
@@ -805,7 +985,7 @@ def lab_to_num(labels: list):
 
 
 def num_to_lab(numbers: list, numbered: bool = True):
-    '''
+    """
     Convert atomic number to atomic labels
 
     Parameters
@@ -819,7 +999,7 @@ def num_to_lab(numbers: list, numbered: bool = True):
     -------
     list
         Atomic labels
-    '''
+    """
 
     labels = [atom_num_lab[num] for num in numbers]
 
@@ -1246,3 +1426,32 @@ def _rotate_and_rmsd(angs: list, coords_1: np.ndarray, coords_2: np.ndarray):
     rmsd = _calculate_rmsd(_coords_1, coords_2)
 
     return rmsd
+
+
+def calculate_com(labels, coords):
+    """
+    Calculates centre-of-mass using relative atomic masses
+    Parameters
+    ----------
+    labels : list
+        list of atomic labels
+    coords : np.ndarray
+        xyz coordinates as (n_atoms, 3) array
+
+    Returns
+    -------
+    np.ndarray
+        xyz coordinates of centre of mass as (3) array
+    """
+
+    labels_nn = remove_numbers(labels)
+
+    masses = [ram_dict[lab] for lab in labels_nn]
+
+    com_coords = np.zeros(3)
+    for trio, mass in zip(coords, masses):
+        com_coords += trio * mass
+
+    com_coords /= np.sum(masses)
+
+    return com_coords
